@@ -236,15 +236,15 @@ WidgetClass abacusWidgetClass = (WidgetClass) & abacusClassRec;
 #endif /* defined(SYSV) || defined(SVR4) */
 
 static int
-usleep(unsigned long usec)
+usleep(unsigned int usec)
 {
 #if (defined (SYSV) || defined(SVR4)) && !defined(__hpux)
 #if defined(HAVE_NANOSLEEP)
 	{
 		struct timespec rqt;
 
-		rqt.tv_nsec = 1000 * (usec % (unsigned long) 1000000);
-		rqt.tv_sec = usec / (unsigned long) 1000000;
+		rqt.tv_nsec = 1000 * (usec % (unsigned int) 1000000);
+		rqt.tv_sec = usec / (unsigned int) 1000000;
 		return nanosleep(&rqt, NULL);
 	}
 #else
@@ -270,8 +270,8 @@ usleep(unsigned long usec)
 
 #endif
 
-	time_out.tv_usec = usec % (unsigned long) 1000000;
-	time_out.tv_sec = usec / (unsigned long) 1000000;
+	time_out.tv_usec = usec % (unsigned int) 1000000;
+	time_out.tv_sec = usec / (unsigned int) 1000000;
 	(void) select(0, (void *) 0, (void *) 0, (void *) 0, &time_out);
 #endif
 #endif
@@ -280,7 +280,7 @@ usleep(unsigned long usec)
 #endif
 
 static void
-Sleep(unsigned long cMilliseconds)
+Sleep(unsigned int cMilliseconds)
 {
 	(void) usleep(cMilliseconds * 1000);
 }
@@ -888,7 +888,7 @@ MoveBeadsUp(AbacusWidget w, int deck, int rail, int j)
 			}
 			if (l + 1 != w->abacus.spaces) {
 				XFlush(XtDisplay(w));
-				Sleep((unsigned long) w->abacus.delay);
+				Sleep((unsigned int) w->abacus.delay);
 			}
 		}
 		if (w->abacus.decks[deck].orientation) {
@@ -919,7 +919,7 @@ MoveBeadsDown(AbacusWidget w, int deck, int rail, int j)
 			}
 			if (l + 1 != w->abacus.spaces) {
 				XFlush(XtDisplay(w));
-				Sleep((unsigned long) w->abacus.delay);
+				Sleep((unsigned int) w->abacus.delay);
 			}
 		}
 		if (w->abacus.decks[deck].orientation) {
